|Project| |Version| Documentation
===================================

Contents
------------------------

.. toctree::
    :maxdepth: 2
    
    intro
    tutorial
    api
    api_images
    api_albums
    api_tags
    meta


Indices and tables
-------------------

* :ref:`genindex`
* :ref:`search`

